@@ -18,24 +18,37 @@
 //
 // to contact the author : dar.linux@free.fr
 /*********************************************************************/
-// $Id: sar_tools.hpp,v 1.5.4.1 2004/08/01 06:11:50 edrusb Exp $
+// $Id: sar_tools.hpp,v 1.10 2004/11/07 18:21:38 edrusb Rel $
 //
 /*********************************************************************/
 //
 
+    /// \file sar_tools.hpp
+    /// \brief a set of tools aims to help Segmentation And Reassemblement (sar) class
+
 #ifndef SAR_TOOLS_HPP
 #define SAR_TOOLS_HPP
 
-#include <string>
 #include "../my_config.h"
+
+#include <string>
 #include "integers.hpp"
+#include "infinint.hpp"
 #include "generic_file.hpp"
 
 namespace libdar
 {
 
-    extern generic_file *sar_tools_open_archive_fichier(const std::string &filename, bool allow_over, bool warn_over);
-    extern generic_file *sar_tools_open_archive_tuyau(S_I fd, gf_mode mode);
+	/// \brief create a container for a single sliced archive
+	/// \ingroup Private
+    extern generic_file *sar_tools_open_archive_fichier(user_interaction & dialog,
+							const std::string &filename,
+							bool allow_over, bool warn_over);
+
+	/// \brief create an container to write a archive to a pipe
+	/// \ingroup Private
+    extern generic_file *sar_tools_open_archive_tuyau(user_interaction & dialog,
+						      S_I fd, gf_mode mode);
 
 } // end of namespace
 
